//! Analysis tools from the Ethereum Toolkit.
//!
//! Highly unstable and incomplete.

#![deny(unsafe_code)]
// TODO: #![deny(missing_docs)]
// TODO: #![deny(unreachable_pub)]
#![deny(missing_debug_implementations)]

mod blocks;
pub mod cfg;
mod sym;
